@@ -23,16 +23,15 @@ pub mod primitives;
 #[allow(dead_code)]
 pub mod utils;
 
-/// SewUp help you build up ewasm
-/// The runtime module is used for tesing
-#[cfg(test)]
+#[cfg(not(target_arch = "wasm32"))]
 pub mod runtimes;
 
 #[allow(unused_variables)]
 pub mod types;
 
-#[cfg(feature = "default")]
-#[cfg(test)]
-mod tests;
-
 pub use bincode;
+
+/// Re export the ewasm_api
+/// these api is low level apis, it is better to keep in a library not in the contract file
+#[cfg(target_arch = "wasm32")]
+pub use ewasm_api;
